@@ -7,8 +7,8 @@ struct SPVM_my {
   SPVM_OP* op_my;
   SPVM_TYPE* type;
   SPVM_OP* op_name;
-  int32_t index;
-  int32_t var_id;
+  int32_t id;
+  int32_t mem_id;
   int32_t runtime_type;
   int32_t type_width;
   int8_t is_tmp;
