@@ -14,7 +14,7 @@ enum {
   SPVM_SUB_C_FLAG_ENUM = 4,
   SPVM_SUB_C_FLAG_DESTRUCTOR = 8,
   SPVM_SUB_C_FLAG_OBJECT_TYPE_RETURN = 16,
-  SPVM_SUB_C_FLAG_VALUE_TYPE_RETURN = 32,
+  SPVM_SUB_C_FLAG_MULTI_NUMERIC_TYPE_RETURN = 32,
   SPVM_SUB_C_FLAG_ANON = 64,
   SPVM_SUB_C_FLAG_PRIVATE = 128,
 };
